package IdPAccountManager::Data::TestAccount;

use strict;
use warnings;

use base 'IdPAccountManager::DB::Object';

use POSIX qw(strftime);

__PACKAGE__->meta->setup(
    table   => 'testaccounts',

    columns => [
        id                 => { type => 'bigserial', not_null => 1 },
        user_password_hash => { type => 'varchar', length => 50, not_null => 1 },
        creation_date      => { type => 'integer' },
        expiration_date    => { type => 'integer' },
        account_profile    => { type => 'varchar', length => 100, not_null => 1 },
        sp_entityid        => { type => 'varchar', length => 250, not_null => 1 },
    ],

    primary_key_columns => [ 'id' ],
);

sub print {
    my ($self, $fd) = @_;
    $fd = \*STDOUT unless $fd;

    printf $fd
"Account ID=%s; password_hash=%s; sp_entityid=%s; account_profile=%s; creation_date=%s; expiration_date=%s\n",
      $self->id(),          $self->user_password_hash(),
      $self->sp_entityid(), $self->account_profile(),
      POSIX::strftime('%Y:%m:%d', localtime($self->creation_date())),
      POSIX::strftime('%Y:%m:%d', localtime($self->expiration_date()));
}

sub user_password {
    my ($self) = @_;

    return $self->{user_password};
}

sub save {
    my ($self, %args) = @_;

    # If no ID is defined, it is a new account
    if (! defined $self->id()) {
        $self->{user_password} =
            IdPAccountManager::Tools::generate_password();
        $self->user_password_hash(
            IdPAccountManager::Tools::sha256_hash($self->{user_password}));
        $self->creation_date(time);
        $self->expiration_date(
            time + ($args{'accounts_validity_period'} * 3600 * 24));
    }

    $self->SUPER::save();
}

1;
